@@ -1,5 +1,5 @@
 package HTTP::API::Client;
-$HTTP::API::Client::VERSION = '0.08';
+$HTTP::API::Client::VERSION = '0.09';
 use strict;
 use warnings;
 
@@ -296,6 +296,18 @@ sub delete {
     return $self->send( DELETE => @_ );
 }
 
+sub _execute_callbacks {
+    my ($self, $type, %options) = @_;
+
+    my $sth = $options{$type};
+
+    while (my ($key, $callback) = each %$sth) {
+        next if !defined $callback;
+        next if !UNIVERSAL::isa($callback, 'CODE');
+        $sth->{$key} = $self->$callback(key => $key, %options);
+    }
+}
+
 sub send {
     my $self         = shift;
     my $method       = shift || "GET";
@@ -303,6 +315,13 @@ sub send {
     my $data         = shift || {};
     my $headers      = shift || {};
 
+    my %options = (
+        method  => \$method,
+        path    => \$path,
+        data    => $data,
+        headers => $headers,
+    );
+
     if ( my $pd = $self->pre_defined_data ) {
         %$data = ( %$pd, %$data );
     }
@@ -311,6 +330,9 @@ sub send {
         %$headers = ( %$ph, %$headers );
     }
 
+    $self->_execute_callbacks(data    => %options);
+    $self->_execute_callbacks(headers => %options);
+
     my $ua           = $self->ua;
     my $base_url     = $self->base_url;
     my $url          = $base_url ? $base_url . $path : $path;
